@@ -262,6 +262,39 @@ class ContentNode(object):
             self._feature_map[new_feature.feature_type + ":" + new_feature.name] = new_feature
             return new_feature
 
+    def delete_children(self, nodes: Optional[List] = None,
+                        exclude_nodes: Optional[List] = None):
+        """Delete the children of this node, you can either supply a list of the nodes to delete
+           or the nodes to exclude from the delete, if neither are supplied then we delete all the children.
+
+           Note there is precedence in place, if you have provided a list of nodes to delete then the nodes
+           to exclude is ignored.
+
+           :param nodes:Optional[List[ContentNode]] a list of content nodes that are children to delete
+           :param exclude_nodes:Optional[List[ContentNode]] a list of content node that are children not to delete
+
+        """
+        children_to_delete = []
+
+        for child_node in self.children:
+            if nodes is not None:
+                for node_to_delete in nodes:
+                    if node_to_delete.uuid == child_node.uuid:
+                        children_to_delete.append(child_node)
+            elif exclude_nodes is not None:
+                if len(exclude_nodes) == 0:
+                    children_to_delete.append(child_node)
+                else:
+                    for nodes_to_exclude in exclude_nodes:
+                        if nodes_to_exclude.uuid != child_node.uuid:
+                            children_to_delete.append(child_node)
+            else:
+                children_to_delete.append(child_node)
+
+        for child_to_delete in children_to_delete:
+            if child_to_delete in self.children:
+                self.children.remove(child_to_delete)
+
     def get_feature(self, feature_type, name):
         """
         Gets the value for the given feature.
@@ -1455,6 +1488,19 @@ class Document(object):
 class DocumentStore:
     """A document store supports storing, listing and retrieving Kodexa documents"""
 
+    def get(self, path: str) -> Document:
+        pass
+
+    def list(self) -> List[Dict]:
+        pass
+
+    def put(self, path: str, document: Document):
+        pass
+
+
+class FileStore:
+    """A file store supports storing, listing and retrieving native files"""
+
     def get(self, path: str) -> Document:
         pass
 
@@ -1463,3 +1509,13 @@ class DocumentStore:
 
     def put(self, path: str, document: Document):
         pass
+
+
+class ModelStore:
+    """A model store supports storing and retrieving of a ML models"""
+
+    def get(self, path: str) -> Document:
+        pass
+
+    def put(self, path: str, document: Document):
+        pass
