@@ -48,7 +48,7 @@ class ContentObject:
         return {
             'id': self.id,
             'tags': self.tags,
-            'content_type': self.content_type,
+            'content_type': self.content_type.name,
             'metadata': self.metadata,
             'name': self.name
         }
